@@ -799,16 +799,15 @@ final class WeakMap implements ArrayAccess, Countable, IteratorAggregate
 }
 
 /**
- * Stringable interface marks classes as available for serialization
- * in a string.
+ * Stringable interface denotes a class as having a __toString() method.
  *
  * @since 8.0
  */
 interface Stringable
 {
     /**
-     * Magic method {@see https://www.php.net/manual/en/language.oop5.magic.php}
-     * called during serialization to string.
+     * Magic method {@see https://www.php.net/manual/en/language.oop5.magic.php#object.tostring}
+     * allows a class to decide how it will react when it is treated like a string.
      *
      * @return string Returns string representation of the object that
      * implements this interface (and/or "__toString" magic method).
@@ -907,7 +906,7 @@ interface UnitEnum
  */
 interface BackedEnum extends UnitEnum
 {
-    public readonly string $value;
+    public readonly int|string $value;
 
     /**
      * @param int|string $value
