@@ -763,6 +763,9 @@ class PDO
 
     #[Deprecated("Use PDO::ATTR_EMULATE_PREPARES instead")]
     public const PGSQL_ASSOC = 1;
+    /**
+     * @removed 7.1
+     */
     public const PGSQL_ATTR_DISABLE_NATIVE_PREPARED_STATEMENT = 1000;
 
     /**
@@ -899,6 +902,21 @@ class PDO
      */
     public const OCI_ATTR_CALL_TIMEOUT = 1004;
 
+    /**
+     * Sets the date format.
+     */
+    public const FB_ATTR_DATE_FORMAT = 1000;
+
+    /**
+     * Sets the time format.
+     */
+    public const FB_ATTR_TIME_FORMAT = 1001;
+
+    /**
+     * Sets the timestamp format.
+     */
+    public const FB_ATTR_TIMESTAMP_FORMAT = 1002;
+
     /**
      * (PHP 5 &gt;= 5.1.0, PHP 7, PECL pdo &gt;= 0.1.0)<br/>
      * Creates a PDO instance representing a connection to a database
